@@ -12,24 +12,20 @@
 #
 ##############################################################################
 """Unit tests
-
 """
-__docformat__ = "reStructuredText"
-
+import doctest
 import unittest
 
-from zope.testing import doctest
-import zope.app.testing.functional
+from zc.sourcefactory.tests import setUp
+from zc.sourcefactory.tests import tearDown
 
-from zc.sourcefactory.tests import SourceFactoryLayer
 
 def test_suite():
-    suite = unittest.TestSuite()
-    token = zope.app.testing.functional.FunctionalDocFileSuite('token.txt')
-    token.layer = SourceFactoryLayer
-    readme =  zope.app.testing.functional.FunctionalDocFileSuite(
-            'README.txt', optionflags=doctest.ELLIPSIS)
-    readme.layer = SourceFactoryLayer
-    suite.addTest(token)
-    suite.addTest(readme)
-    return suite
+    return unittest.TestSuite((
+        doctest.DocFileSuite(
+            'token.txt', setUp=setUp, tearDown=tearDown,
+            optionflags=doctest.ELLIPSIS),
+        doctest.DocFileSuite(
+            'README.txt', setUp=setUp, tearDown=tearDown,
+            optionflags=doctest.ELLIPSIS),
+    ))
